@@ -58,4 +58,37 @@ class S3Client(Boto3Client):
         parameters = json.load(open('tmp.json', 'r'))
         os.remove('tmp.json')
         return parameters
-        
\ No newline at end of file
+        
+    def get_vocab(self,
+                  bucket: str,
+                  project_name: str) -> dict:
+        """
+        """
+        vocab = self.get_object(Bucket=bucket, Key=f"{project_name}/config/vocab.json")
+        return json.loads(vocab['Body'].read())
+    
+    def upload_vocab(self,
+                     bucket: str,
+                     project_name: str,
+                     vocab: dict):
+        """
+        """
+        self.put_object(Body=json.dumps(vocab).encode(), Bucket=bucket, Key=f"{project_name}/config/vocab.json")
+            
+    def get_word2idx(self,
+                     bucket: str,
+                     project_name: str) -> dict:
+        """
+        """
+        vocab = self.get_object(Bucket=bucket, Key=f"{project_name}/config/word2idx.json")
+        return json.loads(vocab['Body'].read())
+    
+    def upload_word2idx(self,
+                        bucket: str,
+                        project_name: str,
+                        word2idx: dict):
+        """
+        """
+        self.put_object(Body=json.dumps(word2idx).encode(), Bucket=bucket, Key=f"{project_name}/config/word2idx.json")
+    
+    
\ No newline at end of file
