@@ -38,3 +38,21 @@ class SQSClient(Boto3Client):
             QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/ocr-queue",
             MessageBody=json.dumps(msg_body)
         )
+
+    def empty_preprocess(self):
+        """
+        """
+        num_msgs = self.get_queue_attributes(
+            QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/preprocess-queue",
+            Attributes=['ApproximateNumberOfMessages']
+        )['Attributes']['ApproximateNumberOfMessages']
+        return num_msgs == 0
+        
+    def empty_ocr(self):
+        """
+        """
+        num_msgs = self.get_queue_attributes(
+            QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/ocr-queue",
+            Attributes=['ApproximateNumberOfMessages']
+        )['Attributes']['ApproximateNumberOfMessages']
+        return num_msgs == 0
\ No newline at end of file
